@@ -8,11 +8,17 @@
 #' `innsight` package. Implemented are the following methods:
 #'
 #' - *Deep Learning Important Features* ([`DeepLift`])
+#' - *Deep Shapley additive explanations* ([`DeepSHAP`])
 #' - *Layer-wise Relevance Propagation* ([`LRP`])
 #' - Gradient-based methods:
 #'    - *Vanilla gradients* including *Gradient\eqn{\times}Input* ([`Gradient`])
 #'    - Smoothed gradients including *SmoothGrad\eqn{\times}Input* ([`SmoothGrad`])
+#'    - *Integrated gradients* ([`IntegratedGradient`])
+#'    - *Expected gradients* ([`ExpectedGradient`])
 #' - *Connection Weights* (global and local) ([`ConnectionWeights`])
+#' - Also some model-agnostic approaches:
+#'    - *Local interpretable model-agnostic explanations* ([`LIME`])
+#'    - *Shapley values* ([`SHAP`])
 #'
 #' @template param-converter
 #' @template param-data
@@ -20,6 +26,7 @@
 #' @template param-ignore_last_act
 #' @template param-dtype
 #' @template param-aggr_channels
+#' @template param-output_label
 #' @template param-as_plotly
 #' @template param-verbose
 #' @template param-ref_data_idx
@@ -34,9 +41,23 @@
 #' @template field-ignore_last_act
 #' @template field-result
 #' @template field-output_idx
+#' @template field-output_label
 #' @template field-verbose
 #' @template field-winner_takes_all
 #'
+#' @field preds (`list`)\cr
+#' In this field, all calculated predictions are stored as a list of
+#' `torch_tensor`s. Each output layer has its own list entry and contains
+#' the respective predicted values.\cr
+#' @field decomp_goal (`list`)\cr
+#' In this field, the method-specific decomposition objectives are stored as
+#' a list of `torch_tensor`s for each output layer. For example,
+#' GradientxInput and LRP attempt to decompose the prediction into
+#' feature-wise additive effects. DeepLift and IntegratedGradient decompose
+#' the difference between \eqn{f(x)} and \eqn{f(x')}. On the other hand,
+#' DeepSHAP and ExpectedGradient aim to decompose \eqn{f(x)} minus the
+#' averaged prediction across the reference values.\cr
+#'
 InterpretingMethod <- R6Class(
   classname = "InterpretingMethod",
   public = list(
@@ -48,7 +69,10 @@ InterpretingMethod <- R6Class(
     ignore_last_act = NULL,
     result = NULL,
     output_idx = NULL,
+    output_label = NULL,
     verbose = NULL,
+    preds = NULL,
+    decomp_goal = NULL,
 
     #' @description
     #' Create a new instance of this super class.
@@ -78,6 +102,7 @@ InterpretingMethod <- R6Class(
     initialize = function(converter, data,
                           channels_first = TRUE,
                           output_idx = NULL,
+                          output_label = NULL,
                           ignore_last_act = TRUE,
                           winner_takes_all = TRUE,
                           verbose = interactive(),
@@ -101,8 +126,11 @@ InterpretingMethod <- R6Class(
       self$dtype <- dtype
       self$converter$model$set_dtype(dtype)
 
-      # Check output indices
-      self$output_idx <- check_output_idx(output_idx, converter$output_dim)
+      # Check output indices and labels
+      outputs <- check_output_idx(output_idx, converter$output_dim,
+                                  output_label, converter$output_names)
+      self$output_idx <- outputs[[1]]
+      self$output_label <- outputs[[2]]
 
       self$data <- private$test_data(data)
     },
@@ -155,11 +183,23 @@ InterpretingMethod <- R6Class(
           result <- apply_results(result, FUN)
         }
 
+        # Prepare predictions
+        prepare_preds <- function(x) {
+          if (is.null(unlist(x))) {
+            NULL
+          } else {
+            lapply(seq_along(x), function(i) as.array(x[[i]]))
+          }
+        }
+        preds <- prepare_preds(self$preds)
+        decomp_goals <- prepare_preds(self$decomp_goal)
+
         # Convert the torch_tensor result into a data.frame
         result <- create_dataframe_from_result(
           seq_len(dim(self$data[[1]])[1]), result,
           self$converter$input_names, self$converter$output_names,
-          self$output_idx)
+          self$output_idx, preds, decomp_goals)
+
         # Remove unnecessary columns
         if (all(result$input_dimension <= 2)) {
           result$feature_2 <- NULL
@@ -215,6 +255,9 @@ InterpretingMethod <- R6Class(
     #' `'gridExtra'` and `'gtable'` must be installed in your R session.
     #' 3. If the global *Connection Weights* method was applied, the
     #' unnecessary argument `data_idx` will be ignored.
+    #' 4. The predictions, the sum of relevances, and, if available, the
+    #' decomposition target are displayed by default in a box within the plot.
+    #' Currently, these are not generated for `plotly` plots.
     #'
     #' @param data_idx (`integer`)\cr
     #' An integer vector containing the numbers of the data
@@ -234,6 +277,13 @@ InterpretingMethod <- R6Class(
     #' same fill scale across multiple input layers or whether each is
     #' scaled individually. This argument is only used if more than one input
     #' layer results are plotted.\cr
+    #' @param show_preds (`logical`)\cr
+    #' This logical value indicates whether the plots display the prediction,
+    #' the sum of calculated relevances, and, if available, the targeted
+    #' decomposition value. For example, in the case of GradientxInput, the
+    #' goal is to obtain a decomposition of the predicted value, while for
+    #'  DeepLift and IntegratedGradient, the goal is the difference between
+    #'  the prediction and the reference value, i.e., \eqn{f(x) - f(x')}.\cr
     #'
     #' @return
     #' Returns either an [`innsight_ggplot2`] (`as_plotly = FALSE`) or an
@@ -242,10 +292,13 @@ InterpretingMethod <- R6Class(
     #'
     plot = function(data_idx = 1,
                     output_idx = NULL,
+                    output_label = NULL,
                     aggr_channels = "sum",
                     as_plotly = FALSE,
-                    same_scale = FALSE) {
+                    same_scale = FALSE,
+                    show_preds = TRUE) {
 
+      # Get method-specific arguments -----------------------------------------
       if (inherits(self, "ConnectionWeights")) {
         if (!self$times_input) {
           if (!identical(data_idx, 1)) {
@@ -267,28 +320,48 @@ InterpretingMethod <- R6Class(
       } else if (inherits(self, "LRP")) {
         value_name <- "Relevance"
         include_data <- TRUE
-      } else if (inherits(self, "DeepLift")) {
+      } else if (inherits(self, c("DeepLift", "DeepSHAP"))) {
         value_name <- "Contribution"
         include_data <- TRUE
       } else if (inherits(self, "GradientBased")) {
-        value_name <- "Gradient"
+        value_name <- if(self$times_input) "Relevance" else "Gradient"
+        include_data <- TRUE
+      } else if (inherits(self, "LIME")) {
+        value_name <- "Weight"
+        include_data <- TRUE
+      } else if (inherits(self, "SHAP")) {
+        value_name <- "Shapley Value"
         include_data <- TRUE
       }
 
-      # Check correctness of arguments
+      # Check correctness of arguments ----------------------------------------
       cli_check(
         checkIntegerish(data_idx, lower = 1, upper = dim(self$data[[1]])[1]),
         "data_idx")
-      output_idx <- check_output_idx_for_plot(output_idx, self$output_idx)
       cli_check(checkLogical(as_plotly), "as_plotly")
       cli_check(checkLogical(same_scale), "same_scale")
 
       # Set aggregation function for channels
       aggr_channels <- get_aggr_function(aggr_channels)
 
-      # Get only relevant model outputs
+      # Check for output_label and output_idx
+      if (!is.null(output_label) & is.null(output_idx)) {
+        output_idx <- transform_label_to_idx(output_label,
+                                             self$converter$output_names)
+      } else if (!is.null(output_label) & !is.null(output_idx)) {
+        warningf("You passed non-{.code NULL} values for the arguments ",
+                 "{.arg output_label} and {.arg output_idx}. Both are used ",
+                 "to specify the output nodes to be plotted. In the ",
+                 "following, only the values of {.arg output_idx} are used!")
+      }
+      output_idx <- check_output_idx_for_plot(output_idx, self$output_idx)
+
+      # Get only the relevant results -----------------------------------------
+      # Get only relevant model output layer
       null_idx <- unlist(lapply(output_idx, is.null))
       result <- self$result[!null_idx]
+      preds <- if (length(self$preds) != 0) self$preds[!null_idx] else NULL
+      decomp_goals <- if (length(self$decomp_goal) != 0) self$decomp_goal[!null_idx] else NULL
 
       # Get the relevant output and class node indices
       # This is done by matching the given output indices ('output_idx') with
@@ -298,8 +371,28 @@ InterpretingMethod <- R6Class(
         seq_along(output_idx),
         function(i) match(output_idx[[i]], self$output_idx[[i]]))[!null_idx]
 
-      result <- apply_results(result, aggregate_channels, idx_matches, data_idx,
-                              self$channels_first, aggr_channels)
+      # Get only the relevant results, predictions and decomposition goals
+      result <- apply_results(result, aggregate_channels, idx_matches,
+                              data_idx, self$channels_first, aggr_channels)
+      if (show_preds) {
+        fun <- function(i, x) {
+          as.array(x[[i]][data_idx, idx_matches[[i]], drop = FALSE])
+        }
+        if (!is.null(unlist(preds))) {
+          preds <- lapply(seq_along(preds), fun, x = preds)
+        } else {
+          preds = NULL
+        }
+        if (!is.null(unlist(decomp_goals))) {
+          decomp_goals <- lapply(seq_along(decomp_goals), fun, x = decomp_goals)
+        } else {
+          decomp_goals = NULL
+        }
+      } else {
+        preds = NULL
+        decomp_goals = NULL
+      }
+
 
       # Get and modify input names
       input_names <- lapply(self$converter$input_names, function(in_name) {
@@ -309,8 +402,10 @@ InterpretingMethod <- R6Class(
         in_name
       })
 
+      # Create the data.frame with all information necessary for the plot
       result_df <- create_dataframe_from_result(
-        data_idx, result, input_names, self$converter$output_names, output_idx)
+        data_idx, result, input_names, self$converter$output_names, output_idx,
+        preds, decomp_goals)
 
       # Get plot
       if (as_plotly) {
@@ -318,7 +413,7 @@ InterpretingMethod <- R6Class(
                            same_scale)
       } else {
         p <- create_ggplot(result_df, value_name, include_data, FALSE, NULL,
-                           same_scale)
+                           same_scale, show_preds)
       }
 
       p
@@ -326,7 +421,7 @@ InterpretingMethod <- R6Class(
 
     #' @description
     #' This method visualizes the results of the selected method summarized as
-    #' boxplots and enables a visual in-depth investigation of the global
+    #' boxplots/median image and enables a visual in-depth investigation of the global
     #' behavior with the help of the S4 classes [`innsight_ggplot2`] and
     #' [`innsight_plotly`].\cr
     #' You can use the argument `output_idx` to select the individual output
@@ -367,15 +462,17 @@ InterpretingMethod <- R6Class(
     #' Returns either an [`innsight_ggplot2`] (`as_plotly = FALSE`) or an
     #' [`innsight_plotly`] (`as_plotly = TRUE`) object with the plotted
     #' summarized results.
-    boxplot = function(output_idx = NULL,
-                       data_idx = "all",
-                       ref_data_idx = NULL,
-                       aggr_channels = "sum",
-                       preprocess_FUN = abs,
-                       as_plotly = FALSE,
-                       individual_data_idx = NULL,
-                       individual_max = 20) {
+    plot_global = function(output_idx = NULL,
+                           output_label = NULL,
+                           data_idx = "all",
+                           ref_data_idx = NULL,
+                           aggr_channels = "sum",
+                           preprocess_FUN = abs,
+                           as_plotly = FALSE,
+                           individual_data_idx = NULL,
+                           individual_max = 20) {
 
+      # Get method-specific arguments -----------------------------------------
       if (inherits(self, "ConnectionWeights")) {
         if (!self$times_input) {
           stopf(
@@ -389,18 +486,17 @@ InterpretingMethod <- R6Class(
         value_name <- "Relative Importance"
       } else if (inherits(self, "LRP")) {
         value_name <- "Relevance"
-      } else if (inherits(self, "DeepLift")) {
+      } else if (inherits(self, c("DeepLift", "DeepSHAP"))) {
         value_name <- "Contribution"
       } else if (inherits(self, "GradientBased")) {
-        value_name <- "Gradient"
+        value_name <- if(self$times_input) "Relevance" else "Gradient"
+      } else if (inherits(self, "LIME")) {
+        value_name <- "Weight"
+      } else if (inherits(self, "SHAP")) {
+        value_name <- "Shapley Value"
       }
 
-      #
-      # Do checks
-      #
-
-      # output_idx
-      output_idx <- check_output_idx_for_plot(output_idx, self$output_idx)
+      # Check correctness of arguments ----------------------------------------
       # data_idx
       num_data <- dim(self$data[[1]])[1]
       if (identical(data_idx, "all")) {
@@ -428,6 +524,18 @@ InterpretingMethod <- R6Class(
       cli_check(checkInt(individual_max, lower = 1), "individual_max")
       individual_max <- min(individual_max, num_data)
 
+      # Check for output_label and output_idx
+      if (!is.null(output_label) & is.null(output_idx)) {
+        output_idx <- transform_label_to_idx(output_label,
+                                             self$converter$output_names)
+      } else if (!is.null(output_label) & !is.null(output_idx)) {
+        warningf("You passed non-{.code NULL} values for the arguments ",
+                 "{.arg output_label} and {.arg output_idx}. Both are used ",
+                 "to specify the output nodes to be plotted. In the ",
+                 "following, only the values of {.arg output_idx} are used!")
+      }
+      output_idx <- check_output_idx_for_plot(output_idx, self$output_idx)
+
       # Set the individual instances for the plot
       if (!as_plotly) {
         individual_idx <- ref_data_idx
@@ -437,7 +545,7 @@ InterpretingMethod <- R6Class(
         individual_idx <- individual_idx[!is.na(individual_idx)]
       }
 
-
+      # Get only the relevant results -----------------------------------------
       # Get only relevant model outputs
       null_idx <- unlist(lapply(output_idx, is.null))
       result <- self$result[!null_idx]
@@ -450,7 +558,7 @@ InterpretingMethod <- R6Class(
         seq_along(output_idx),
         function(i) match(output_idx[[i]], self$output_idx[[i]]))[!null_idx]
 
-      # apply preprocess function
+      # Apply preprocess function ---------------------------------------------
       preprocess <- function(result, out_idx, in_idx, idx_matches) {
         res <- result[[out_idx]][[in_idx]]
         if (is.null(res)) {
@@ -472,7 +580,8 @@ InterpretingMethod <- R6Class(
       })
 
       idx <- sort(unique(c(individual_idx, data_idx)))
-      # Create boxplot data
+
+      # Create boxplot data and plots -----------------------------------------
       result <-
         apply_results(result, aggregate_channels, idx_matches, idx,
                       self$channels_first, aggr_channels)
@@ -530,11 +639,17 @@ InterpretingMethod <- R6Class(
   private = list(
 
     # ----------------------- backward Function -------------------------------
-    run = function(method_name) { # only 'LRP' or 'DeepLift'
+    run = function(method_name, reset = TRUE) {
 
       # Declare vector for relevances for each output node
       rel_list <- vector(mode = "list",
                          length = length(self$converter$model$output_nodes))
+      # Declare vector for the predictions for each output node
+      pred_list <- vector(mode = "list",
+                          length = length(self$converter$model$output_nodes))
+      # Declare vector for the decomposition goal for each output node
+      decomp_list <- vector(mode = "list",
+                            length = length(self$converter$model$output_nodes))
 
       if (self$verbose) {
         #messagef("Backward pass '", method_name, "':")
@@ -563,6 +678,7 @@ InterpretingMethod <- R6Class(
           # relevances for this output
           if (is.null(self$output_idx[[idx]])) {
             rel <- NULL
+            pred <- NULL
           } else {
             # Otherwise ...
             # get the corresponding output depending on the argument
@@ -580,8 +696,25 @@ InterpretingMethod <- R6Class(
               }
             }
 
+            # Save the prediction
+            pred <- layer$output
+            decomp_goal <- out
+            if (method_name %in% c("DeepLift", "DeepSHAP")) {
+              if (self$ignore_last_act) {
+                pred_ref <- layer$preactivation_ref
+              } else {
+                pred_ref <- layer$output_ref
+              }
+              num_samples <- dim(self$data[[1]])[1]
+              decomp_goal <- torch_stack((out - pred_ref)$chunk(num_samples),
+                                  dim = 1)$mean(2)
+              pred <- torch_stack(pred$chunk(num_samples), dim = 1)$mean(2)
+            }
+            pred_list[[idx]] <- pred[, self$output_idx[[idx]], drop = FALSE]
+            decomp_list[[idx]] <- decomp_goal[, self$output_idx[[idx]], drop = FALSE]
+
             # For DeepLift, we only need ones
-            if (method_name == "DeepLift") {
+            if (method_name %in% c("DeepLift", "DeepSHAP")) {
               rel <- torch_diag_embed(torch_ones_like(out))
               # Overwrite rule name
               if (self$ignore_last_act) {
@@ -655,15 +788,17 @@ InterpretingMethod <- R6Class(
             rel <- layer$get_input_relevances(rel, rule_name = lrp_rule$rule_name,
                                               rule_param = lrp_rule$rule_param,
                                               winner_takes_all = self$winner_takes_all)
-          } else if (method_name == "DeepLift") {
+          } else if (method_name %in% c("DeepLift", "DeepSHAP")) {
             rel <- layer$get_input_multiplier(rel, rule_name = rule_name,
-                                              winner_takes_all = self$winner_takes_all)
+                                              winner_takes_all = self$winner_takes_all,
+                                              use_grad_near_zero = TRUE)
           } else if (method_name == "Connection-Weights") {
             rel <- layer$get_gradient(rel, weight = layer$W,
                                       use_avgpool = !self$winner_takes_all)
           }
         }
-        layer$reset()
+
+        if (reset) layer$reset()
 
         # Transform it back to a list
         if (!is.list(rel)) {
@@ -686,6 +821,10 @@ InterpretingMethod <- R6Class(
         }
       }
 
+      # Save output predictions
+      self$preds <- pred_list
+      self$decomp_goal <- decomp_list
+
       if (self$verbose) cli_progress_done()
 
       # If necessary, move channels last
@@ -712,9 +851,9 @@ InterpretingMethod <- R6Class(
         }
       }
 
-      # For the DeepLift method, we only get the multiplier. Hence, we have
-      # to multiply this by the differences of inputs
-      if (method_name == "DeepLift") {
+      # For the DeepLift method, we only get the multiplier.
+      # Hence, we have to multiply this by the differences of inputs
+      if (method_name %in% c("DeepLift")) {
         fun <- function(result, out_idx, in_idx, x, x_ref) {
           res <- result[[out_idx]][[in_idx]]
           if (is.null(res)) {
@@ -745,14 +884,17 @@ InterpretingMethod <- R6Class(
           if (is.data.frame(input_data)) {
             input_data <- as.matrix(input_data)
           }
-          as.array(input_data)
+          input_data <- as.array(input_data)
+          assertNumeric(input_data)
+          input_data
         },
         error = function(e) {
           stopf("Failed to convert the argument {.arg ", name,
-               "[[", i, "]]} to an array ",
+               "[[", i, "]]} to a numeric array ",
                "using the function {.fn base::as.array}. The class of your ",
                "argument {.arg ", name, "[[", i, "]]}: '",
-               paste(class(input_data), collapse = "', '"), "'")
+               paste(class(input_data), collapse = "', '"), "'",
+               " (of type: '", paste(typeof(input_data), collapse = "', '"), "')")
         })
 
         ordered_dim <- self$converter$input_dim[[i]]
@@ -798,7 +940,8 @@ InterpretingMethod <- R6Class(
 #' [`InterpretingMethod`] for details.
 #'
 #' @param x An object of the class [`InterpretingMethod`] including the
-#' subclasses [`Gradient`], [`SmoothGrad`], [`LRP`], [`DeepLift`] and
+#' subclasses [`Gradient`], [`SmoothGrad`], [`LRP`], [`DeepLift`],
+#' [`DeepSHAP`], [`IntegratedGradient`], [`ExpectedGradient`] and
 #' [`ConnectionWeights`].
 #' @param ... Other arguments specified in the R6 method
 #' `InterpretingMethod$get_result()`. See [`InterpretingMethod`] for details.
@@ -811,6 +954,42 @@ get_result.InterpretingMethod <- function(x, ...) {
   x$get_result(...)
 }
 
+
+#'
+#' @importFrom graphics boxplot
+#' @exportS3Method
+#'
+boxplot.InterpretingMethod <- function(x, ...) {
+  dims <- unlist(lapply(x$converter$input_dim, length))
+  if (any(dims > 2)) {
+    warningf("The {.fn boxplot} function is only intended for tabular or signal ",
+             "data. It is called {.fn plot_global} instead. ")
+  }
+  x$plot_global(...)
+}
+
+
+#' Get the result of an interpretation method
+#'
+#' This is a generic S3 method for the R6 method
+#' `InterpretingMethod$plot_global()`. See the respective method described in
+#' [`InterpretingMethod`] for details.
+#'
+#' @param x An object of the class [`InterpretingMethod`] including the
+#' subclasses [`Gradient`], [`SmoothGrad`], [`LRP`], [`DeepLift`],
+#' [`DeepSHAP`], [`IntegratedGradient`], [`ExpectedGradient`] and
+#' [`ConnectionWeights`].
+#' @param ... Other arguments specified in the R6 method
+#' `InterpretingMethod$plot_global()`. See [`InterpretingMethod`] for details.
+#'
+#' @export
+plot_global <- function(x, ...) UseMethod("plot_global", x)
+
+#' @exportS3Method
+plot_global.InterpretingMethod <- function(x, ...) {
+  x$plot_global(...)
+}
+
 ###############################################################################
 #                           print utility functions
 ###############################################################################
@@ -882,16 +1061,14 @@ print_output_idx <- function(output_idx, out_names) {
 #                                 Utils
 ###############################################################################
 
-check_output_idx <- function(output_idx, output_dim) {
-  # for the default value, choose from the first output the first ten
-  # (maybe less) output nodes
-  if (is.null(output_idx)) {
-    output_idx <- list(1:min(10, output_dim[[1]]))
-  } else if (testIntegerish(output_idx,
-                          lower = 1,
-                          upper = output_dim[[1]])) {
-    # or only a number (assumes the first output)
+check_output_idx <- function(output_idx, output_dim, output_label, output_names) {
+  # Check the output indices --------------------------
+  # Check if output_idx is a single vector
+  if (testIntegerish(output_idx,
+                     lower = 1,
+                     upper = output_dim[[1]])) {
     output_idx <- list(output_idx)
+  # Check if it's a list of vectors
   } else if (testList(output_idx, max.len = length(output_dim))) {
     # the argument output_idx is a list of output_nodes for each output
     n <- 1
@@ -900,25 +1077,88 @@ check_output_idx <- function(output_idx, output_dim) {
       cli_check(checkInt(limit), "limit")
       if (!testIntegerish(output, lower = 1, upper = limit, null.ok = TRUE)) {
         stopf("Assertion on {.arg output_idx[[", n, "]]} failed: Value(s) ",
-             paste(output, collapse = ","), " not <= ", limit, ".")
+              paste(output, collapse = ","), " not <= ", limit, ".")
       }
       n <- n + 1
     }
-  } else {
+  } else if (!is.null(output_idx)) {
     stopf("The argument {.arg output_idx} has to be either a vector with maximum ",
-         "value of '", output_dim[[1]], "' or a list of length '",
-         length(output_dim), "' with maximal values of '",
-         paste(unlist(output_dim), collapse = ","), "'.")
+          "value of '", output_dim[[1]], "' or a list of length '",
+          length(output_dim), "' with maximal values of '",
+          paste(unlist(output_dim), collapse = ","), "'.")
+  }
+
+  # Check the output labels -------------------------
+  # Check if output_label is a single vector
+  if (testCharacter(output_label, min.len = 1, max.len = output_dim[[1]]) ||
+      testFactor(output_label, min.len = 1, max.len = output_dim[[1]])) {
+    # Check if labels are a subset of output_names
+    cli_check(checkSubset(as.factor(output_label), unlist(output_names[[1]])),
+              "output_label")
+    output_label <- list(output_label)
+    # Check if it's a list of vectors
+  } else if (testList(output_label, max.len = length(output_names))) {
+    # the argument output_label is a list of names for each output
+    n <- 1
+    for (output in output_label) {
+      # Check if labels are a subset of output_names
+      cli_check(checkSubset(as.factor(unlist(output)), unlist(output_names[[n]])),
+                "output_label")
+      n <- n + 1
+    }
+  } else if (!is.null(output_label)) {
+    stopf("The argument {.arg output_label} has to be either a vector of ",
+          "characters/factors or a list of vectors of characters/factors!")
+  }
+
+  if (is.null(output_idx) && is.null(output_label)) {
+    output_idx <- list(1:min(10, output_dim[[1]]))
+    output_label <- list(output_names[[1]][[1]][output_idx[[1]]])
+  } else if (is.null(output_idx) && !is.null(output_label)) {
+    output_idx <- list()
+    for (i in seq_along(output_label)) {
+      output_idx[[i]] <- match(output_label[[i]], output_names[[i]][[1]])
+      if (length(output_idx[[i]]) == 0) output_idx[[i]] <- NULL
+    }
+  } else if (is.null(output_label) && !is.null(output_idx)) {
+    output_label <- list()
+    for (i in seq_along(output_idx)) {
+      output_label[[i]] <- output_names[[i]][[1]][output_idx[[i]]]
+    }
   }
 
   # Fill up with NULLs
-  if (length(output_idx) < length(output_dim)) {
-    output_idx <-
-      append(output_idx,
-             rep(list(NULL), length(output_dim) - length(output_idx)))
+  num_layers <- length(output_dim)
+  if (length(output_idx) < num_layers) {
+    output_idx <- append(output_idx,
+                         rep(list(NULL), num_layers - length(output_idx)))
+  }
+  if (length(output_label) < num_layers) {
+    output_label <- append(output_label,
+                           rep(list(NULL), num_layers - length(output_label)))
   }
 
-  output_idx
+  # Check if both are consistent
+  for (i in seq_along(output_dim)) {
+    if (testTRUE(length(output_idx[[i]]) != length(output_label[[i]]))) {
+      stopf("Both the {.arg output_idx} and {.arg output_label} arguments ",
+            "were passed (i.e., not {.code NULL}). However, they do not ",
+            "match and point to different output nodes.")
+    }
+
+    # Get labels from output_idx
+    labels <- output_names[[i]][[1]][output_idx[[i]]]
+    labels_ref <- as.factor(output_label[[i]])
+    if (length(labels) == 0) labels <- NULL
+    if (length(labels_ref) == 0) labels_ref <- NULL
+    if (!testSetEqual(labels, labels_ref)) {
+      stopf("Both the {.arg output_idx} and {.arg output_label} arguments ",
+            "were passed (i.e., not {.code NULL}). However, they do not ",
+            "match and point to different output nodes.")
+    }
+  }
+
+  list(output_idx, output_label)
 }
 
 
@@ -988,7 +1228,8 @@ tensor_list_to_named_array <- function(torch_result, input_names, output_names,
 
 
 create_dataframe_from_result <- function(data_idx, result, input_names,
-                                         output_names, output_idx) {
+                                         output_names, output_idx,
+                                         preds = NULL, decomp_goal = NULL) {
 
   if (length(data_idx) == 0) {
     result_df <- NULL
@@ -1000,8 +1241,9 @@ create_dataframe_from_result <- function(data_idx, result, input_names,
     output_names <- output_names[nonnull_idx]
 
     fun <- function(result, out_idx, in_idx, input_names, output_names,
-                    output_idx, nonnull_idx) {
+                    output_idx, nonnull_idx, preds) {
       res <- result[[out_idx]][[in_idx]]
+
       result_df <-
         create_grid(data_idx, input_names[[in_idx]],
                     output_names[[out_idx]][[1]][output_idx[[out_idx]]])
@@ -1009,6 +1251,27 @@ create_dataframe_from_result <- function(data_idx, result, input_names,
         result_df$value <- NaN
       } else {
         result_df$value <- as.vector(as.array(res))
+        res_sum <- apply(res, c(1, length(dim(res))), sum)
+        num_reps <- nrow(result_df) %/% (length(data_idx) * length(output_idx[[out_idx]]))
+        res_sum <- do.call("rbind", lapply(seq_len(num_reps), function(x) res_sum))
+
+        if (length(preds) == 0) {
+          pred <- NA
+        } else {
+          pred <- preds[[out_idx]]
+          pred <- do.call("rbind", lapply(seq_len(num_reps), function(x) pred))
+        }
+
+        if (length(decomp_goal) == 0) {
+          dec_goal <- NA
+        } else {
+          dec_goal <- decomp_goal[[out_idx]]
+          dec_goal <- do.call("rbind", lapply(seq_len(num_reps), function(x) dec_goal))
+        }
+
+        result_df$pred <- as.vector(pred)
+        result_df$decomp_sum <- as.vector(res_sum)
+        result_df$decomp_goal <- as.vector(dec_goal)
       }
       result_df$model_input <- paste0("Input_", in_idx)
       result_df$model_output <- factor(
@@ -1021,10 +1284,10 @@ create_dataframe_from_result <- function(data_idx, result, input_names,
     }
 
     result <- apply_results(result, fun, input_names, output_names,
-                            output_idx, nonnull_idx)
+                            output_idx, nonnull_idx, preds)
     result_df <- do.call("rbind",
                          lapply(result, function(x) do.call("rbind", x)))
-    result_df <- result_df[, c(1, 8, 9, 3, 4, 2, 5, 7, 6)]
+    result_df <- result_df[, c(1, 11, 12, 3, 4, 2, 5, 7, 8, 9, 10, 6)]
   }
 
   result_df
@@ -1090,6 +1353,25 @@ check_output_idx_for_plot <- function(output_idx, true_output_idx) {
   output_idx
 }
 
+transform_label_to_idx <- function(output_label, output_names) {
+  if (!is.list(output_label)) {
+    output_label <- list(output_label)
+  }
+
+  fun <- function(i) {
+    if (!is.null(output_label[[i]])) {
+      labels <- as.factor(output_label[[i]])
+      out_names <- output_names[[i]][[1]]
+      cli_check(checkSubset(labels, out_names), "output_label")
+      match(labels, out_names)
+    } else {
+      NULL
+    }
+  }
+
+  lapply(seq_along(output_label), fun)
+}
+
 move_channels_last <- function(names) {
   for (idx in seq_along(names)) {
     if (length(names[[idx]]) == 2) { # 1d input
