@@ -144,8 +144,6 @@ test_that("ConnectionWeights (global): Conv1D-Net", {
   # get_result method
   result <- cw_first$get_result()
   expect_equal(dim(result), c(1,3,64,4))
-  expect_equal(dimnames(result),
-               c(list(NULL), converter$input_names[[1]], converter$output_names[[1]]))
   result <- cw_first$get_result("torch.tensor")
   expect_equal(dim(result), c(1,3,64,4))
   result <- cw_first$get_result("data.frame")
@@ -229,8 +227,6 @@ test_that("ConnectionWeights (global): Conv2D-Net", {
   # get_result method
   result <- cw_first$get_result()
   expect_equal(dim(result), c(1,3,32,32,5))
-  expect_equal(dimnames(result),
-               c(list(NULL), converter$input_names[[1]], converter$output_names[[1]]))
   result <- cw_first$get_result("torch.tensor")
   expect_equal(dim(result), c(1,3,32,32,5))
   result <- cw_first$get_result("data.frame")
@@ -246,7 +242,7 @@ test_that("ConnectionWeights (global): Conv2D-Net", {
   expect_s4_class(p, "innsight_plotly")
   p <- plot(cw_first, as_plotly = TRUE, output_idx = c(1,2))
   expect_s4_class(p, "innsight_plotly")
-  expect_error(boxplot(cw_first))
+  expect_error(plot_global(cw_first))
   expect_message(plot(cw_first, data_idx = c(1,3)))
 
   # Test plot function with channels last
@@ -258,7 +254,7 @@ test_that("ConnectionWeights (global): Conv2D-Net", {
   expect_s4_class(p, "innsight_plotly")
   p <- plot(cw_last, as_plotly = TRUE, output_idx = c(1,2))
   expect_s4_class(p, "innsight_plotly")
-  expect_error(boxplot(cw_last))
+  expect_error(plot_global(cw_last))
   expect_message(plot(cw_last, data_idx = c(1,3)))
 })
 
@@ -329,7 +325,7 @@ test_that("ConnectionWeights (global): Keras model with two inputs + two outputs
   expect_s4_class(p, "innsight_plotly")
   p <- plot(cw_first, as_plotly = TRUE, output_idx = list(c(2), c(1)))
   expect_s4_class(p, "innsight_plotly")
-  expect_error(boxplot(cw_first))
+  expect_error(plot_global(cw_first))
   expect_message(plot(cw_first, data_idx = c(1,3)))
 
   # Test plot function with channels last
@@ -341,7 +337,7 @@ test_that("ConnectionWeights (global): Keras model with two inputs + two outputs
   expect_s4_class(p, "innsight_plotly")
   p <- plot(cw_last, as_plotly = TRUE, output_idx = list(c(2), c(1)))
   expect_s4_class(p, "innsight_plotly")
-  expect_error(boxplot(cw_last))
+  expect_error(plot_global(cw_last))
   expect_message(plot(cw_last, data_idx = c(1,3)))
 
 })
@@ -395,8 +391,6 @@ test_that("ConnectionWeights (local): Dense-Net", {
   # get_result method
   result <- cw_first$get_result()
   expect_equal(dim(result), c(10,4,3))
-  expect_equal(dimnames(result),
-               c(list(NULL), converter$input_names[[1]], converter$output_names[[1]]))
   result <- cw_first$get_result("torch.tensor")
   expect_equal(dim(result), c(10,4,3))
   result <- cw_first$get_result("data.frame")
@@ -482,8 +476,6 @@ test_that("ConnectionWeights (local): Conv1D-Net", {
   # get_result method
   result <- cw_first$get_result()
   expect_equal(dim(result), c(10,3,64,4))
-  expect_equal(dimnames(result),
-               c(list(NULL), converter$input_names[[1]], converter$output_names[[1]]))
   result <- cw_first$get_result("torch.tensor")
   expect_equal(dim(result), c(10,3,64,4))
   result <- cw_first$get_result("data.frame")
@@ -575,8 +567,6 @@ test_that("ConnectionWeights (local): Conv2D-Net", {
   # get_result method
   result <- cw_first$get_result()
   expect_equal(dim(result), c(10,3,32,32,5))
-  expect_equal(dimnames(result),
-               c(list(NULL), converter$input_names[[1]], converter$output_names[[1]]))
   result <- cw_first$get_result("torch.tensor")
   expect_equal(dim(result), c(10,3,32,32,5))
   result <- cw_first$get_result("data.frame")
@@ -603,10 +593,10 @@ test_that("ConnectionWeights (local): Conv2D-Net", {
   p <- plot(cw_last, as_plotly = TRUE, output_idx = c(1,2), data_idx = c(1,4))
   expect_s4_class(p, "innsight_plotly")
 
-  # Test boxplot
-  box <- boxplot(cw_first)
+  # Test plot_global
+  box <- plot_global(cw_first)
   expect_s4_class(box, "innsight_ggplot2")
-  box <- boxplot(cw_first, as_plotly = TRUE)
+  box <- plot_global(cw_first, as_plotly = TRUE)
   expect_s4_class(box, "innsight_plotly")
 })
 
@@ -695,9 +685,9 @@ test_that("ConnectionWeights (global): Keras model with two inputs + two outputs
   p <- plot(cw_last, as_plotly = TRUE, output_idx = list(c(2), c(1)))
   expect_s4_class(p, "innsight_plotly")
 
-  # Test boxplot
-  box <- boxplot(cw_first)
+  # Test plot_global
+  box <- plot_global(cw_first)
   expect_s4_class(box, "innsight_ggplot2")
-  box <- boxplot(cw_first, as_plotly = TRUE)
+  box <- plot_global(cw_first, as_plotly = TRUE)
   expect_s4_class(box, "innsight_plotly")
 })
