@@ -13,10 +13,24 @@ test_that("Gradient: Plot and Boxplot", {
   # create an converter for this model
   converter <- Converter$new(nn)
 
-  # Rescale Rule
-  grad <- Gradient$new(converter, data,
-                    dtype = "double",
-  )
+  expect_error(Gradient$new(converter, data, output_idx = c(1, 10)))
+  Gradient$new(converter, data, output_idx = c(1, 2))
+  expect_error(Gradient$new(converter, data, output_idx = list(c(1, 10))))
+  Gradient$new(converter, data, output_idx = list(c(1, 3)))
+  expect_error(Gradient$new(converter, data, output_idx = list(NULL, c(1, 2))))
+  expect_error(Gradient$new(converter, data, output_label = c(1, 2)))
+  expect_error(Gradient$new(converter, data, output_label = c("A", "b")))
+  Gradient$new(converter, data, output_label = c("setosa", "virginica"))
+  Gradient$new(converter, data, output_label = as.factor(c("setosa", "virginica")))
+  Gradient$new(converter, data, output_label = list(c("setosa", "virginica")))
+  expect_error(Gradient$new(converter, data,
+                            output_label =  c("setosa", "virginica"),
+                            output_idx = c(1, 2)))
+  Gradient$new(converter, data, output_label =  c("setosa", "virginica"),
+               output_idx = c(1, 3))
+
+  # ggplot2
+  grad <- Gradient$new(converter, data, dtype = "double")
 
   # ggplot2
 
@@ -408,34 +422,34 @@ test_that("Gradient: Conv2D-Net", {
   p <- plot(grad, aggr_channels = function(x) -abs(sum(x)))
   expect_s4_class(p, "innsight_ggplot2")
 
-  p <- boxplot(grad)
+  p <- plot_global(grad)
   expect_s4_class(p, "innsight_ggplot2")
-  p <- boxplot(grad, preprocess_FUN = identity)
+  p <- plot_global(grad, preprocess_FUN = identity)
   expect_s4_class(p, "innsight_ggplot2")
-  p <- boxplot(grad, preprocess_FUN = function(x) -abs(x))
+  p <- plot_global(grad, preprocess_FUN = function(x) -abs(x))
   expect_s4_class(p, "innsight_ggplot2")
-  p <- boxplot(grad_first)
+  p <- plot_global(grad_first)
   expect_s4_class(p, "innsight_ggplot2")
-  p <- boxplot(grad, output_idx = c(1))
+  p <- plot_global(grad, output_idx = c(1))
   expect_s4_class(p, "innsight_ggplot2")
-  p <- boxplot(grad, data_idx = 1:3)
+  p <- plot_global(grad, data_idx = 1:3)
   expect_s4_class(p, "innsight_ggplot2")
-  p <- boxplot(grad, individual_max = 2, individual_data_idx = 1:2 )
+  p <- plot_global(grad, individual_max = 2, individual_data_idx = 1:2 )
   expect_s4_class(p, "innsight_ggplot2")
 
   skip_if_not_installed("plotly")
   p <- plot(grad, as_plotly = TRUE)
   expect_s4_class(p, "innsight_plotly")
-  p <- boxplot(grad, as_plotly = TRUE)
+  p <- plot_global(grad, as_plotly = TRUE)
   expect_s4_class(p, "innsight_plotly")
-  p <- boxplot(grad, output_idx = c(1), as_plotly = TRUE)
+  p <- plot_global(grad, output_idx = c(1), as_plotly = TRUE)
   expect_s4_class(p, "innsight_plotly")
-  p <- boxplot(grad, data_idx = 1:3, as_plotly = TRUE)
+  p <- plot_global(grad, data_idx = 1:3, as_plotly = TRUE)
   expect_s4_class(p, "innsight_plotly")
-  p <- boxplot(grad, individual_max = 2, individual_data_idx = 1:2,
+  p <- plot_global(grad, individual_max = 2, individual_data_idx = 1:2,
                as_plotly = TRUE)
   expect_s4_class(p, "innsight_plotly")
-  p <- boxplot(grad, as_plotly = TRUE, ref_data_idx = c(3))
+  p <- plot_global(grad, as_plotly = TRUE, ref_data_idx = c(3))
   expect_s4_class(p, "innsight_plotly")
 })
 
